@@ -167,10 +167,18 @@ void ProcessDirectoryJob::process()
         // local stat function.
         // Recall file shall not be ignored (#4420)
         bool isHidden = e.localEntry.isHidden || (f.first[0] == QLatin1Char('.') && f.first != QLatin1String(".sys.admin#recall#"));
-        if (handleExcluded(path._target, e.localEntry.name,
-                e.localEntry.isDirectory || e.serverEntry.isDirectory, isHidden,
-                e.localEntry.isSymLink))
+        if (handleExcluded(path._target,
+                e.localEntry.name,
+                e.localEntry.isDirectory || e.serverEntry.isDirectory,
+                isHidden,
+                e.localEntry.isSymLink)) {
+            // the file only exists in the db
+            if (!e.localEntry.isValid() && e.dbEntry.isValid()) {
+                qCWarning(lcDisco) << "Removing db entry for non exisitng ignored file:" << path._original;
+                _discoveryData->_statedb->deleteFileRecord(path._original, true);
+            }
             continue;
+        }
 
         if (_queryServer == InBlackList || _discoveryData->isInSelectiveSyncBlackList(path._original)) {
             processBlacklisted(path, e.localEntry, e.dbEntry);
@@ -250,16 +258,20 @@ bool ProcessDirectoryJob::handleExcluded(const QString &path, const QString &loc
             if (item->_file.endsWith(QLatin1Char('.'))) {
                 item->_errorString = tr("File names ending with a period are not supported on this file system.");
             } else {
-                const auto unsupportedCharacters = QStringLiteral("\\:?*\"<>|");
-                for (const auto &x : unsupportedCharacters) {
-                    if (item->_file.contains(x)) {
-                        item->_errorString = tr("File names containing the character '%1' are not supported on this file system.")
-                                                 .arg(x);
-                        break;
+                const auto unsupportedCharacter = [](const QString &fName) {
+                    const auto unsupportedCharacter = QStringLiteral("\\:?*\"<>|");
+                    for (const auto &x : unsupportedCharacter) {
+                        if (fName.contains(x)) {
+                            return x;
+                        }
                     }
-                }
+                    return QChar();
+                }(item->_file);
 
-                if (isInvalidPattern) {
+                if (!unsupportedCharacter.isNull()) {
+                    item->_errorString = tr("File names containing the character '%1' are not supported on this file system.")
+                                             .arg(unsupportedCharacter);
+                } else if (isInvalidPattern) {
                     item->_errorString = tr("File name contains at least one invalid character");
                 } else {
                     item->_errorString = tr("The file name is a reserved name on this file system.");
@@ -301,7 +313,7 @@ bool ProcessDirectoryJob::handleExcluded(const QString &path, const QString &loc
     return true;
 }
 
-void ProcessDirectoryJob::processFile(PathTuple path,
+void ProcessDirectoryJob::processFile(const PathTuple &path,
     const LocalInfo &localEntry, const RemoteInfo &serverEntry,
     const SyncJournalFileRecord &dbEntry)
 {
@@ -366,12 +378,12 @@ void ProcessDirectoryJob::processFile(PathTuple path,
 // Returns true if the checksum was successfully computed
 static bool computeLocalChecksum(const QByteArray &header, const QString &path, const SyncFileItemPtr &item)
 {
-    auto type = parseChecksumHeaderType(header);
-    if (!type.isEmpty()) {
+    const auto checksumHeader = ChecksumHeader::parseChecksumHeader(header);
+    if (checksumHeader.isValid()) {
         // TODO: compute async?
-        QByteArray checksum = ComputeChecksum::computeNowOnFile(path, type);
+        QByteArray checksum = ComputeChecksum::computeNowOnFile(path, checksumHeader.type());
         if (!checksum.isEmpty()) {
-            item->_checksumHeader = makeChecksumHeader(type, checksum);
+            item->_checksumHeader = ChecksumHeader(checksumHeader.type(), checksum).makeChecksumHeader();
             return true;
         }
     }
@@ -426,7 +438,7 @@ void ProcessDirectoryJob::processFileAnalyzeRemoteInfo(
             item->_direction = SyncFileItem::Down;
             item->_instruction = CSYNC_INSTRUCTION_SYNC;
             item->_type = ItemTypeVirtualFileDownload;
-        } else if (dbEntry._etag != serverEntry.etag) {
+        } else if (dbEntry._etag != serverEntry.etag.toUtf8()) {
             item->_direction = SyncFileItem::Down;
             item->_modtime = serverEntry.modtime;
             item->_size = serverEntry.size;
@@ -527,7 +539,7 @@ void ProcessDirectoryJob::processFileAnalyzeRemoteInfo(
             done = true;
             return;
         }
-        if (!serverEntry.isDirectory && base._etag != serverEntry.etag) {
+        if (!serverEntry.isDirectory && base._etag != serverEntry.etag.toUtf8()) {
             /* File with different etag, don't do a rename, but download the file again */
             qCInfo(lcDisco, "file etag different, not a rename");
             done = true;
@@ -591,25 +603,27 @@ void ProcessDirectoryJob::processFileAnalyzeRemoteInfo(
         } else {
             // we need to make a request to the server to know that the original file is deleted on the server
             _pendingAsyncJobs++;
-            auto job = new RequestEtagJob(_discoveryData->_account, _discoveryData->_remoteFolder + originalPath, this);
-            connect(job, &RequestEtagJob::finishedWithResult, this, [=](const HttpResult<QByteArray> &etag) mutable {
+            auto job = new RequestEtagJob(_discoveryData->_account, _discoveryData->_baseUrl, _discoveryData->_remoteFolder + originalPath, this);
+            connect(job, &RequestEtagJob::finishedSignal, this, [=]() mutable {
                 _pendingAsyncJobs--;
                 QTimer::singleShot(0, _discoveryData, &DiscoveryPhase::scheduleMoreJobs);
-                if (etag || etag.error().code != 404 ||
+                if (job->httpStatusCode() == 207 ||
                     // Somehow another item claimed this original path, consider as if it existed
                     _discoveryData->isRenamed(originalPath)) {
                     // If the file exist or if there is another error, consider it is a new file.
                     postProcessServerNew();
                     return;
+                } else if (OC_ENSURE(job->httpStatusCode() == 404)) {
+                    // The file do not exist, it is a rename
+
+                    // In case the deleted item was discovered in parallel
+                    _discoveryData->findAndCancelDeletedJob(originalPath);
+
+                    postProcessRename(path);
+                    processFileFinalize(item, path, item->isDirectory(), item->_instruction == CSYNC_INSTRUCTION_RENAME ? NormalQuery : ParentDontExist, _queryServer);
+                    return;
                 }
-
-                // The file do not exist, it is a rename
-
-                // In case the deleted item was discovered in parallel
-                _discoveryData->findAndCancelDeletedJob(originalPath);
-
-                postProcessRename(path);
-                processFileFinalize(item, path, item->isDirectory(), item->_instruction == CSYNC_INSTRUCTION_RENAME ? NormalQuery : ParentDontExist, _queryServer);
+                abort();
             });
             job->start();
             done = true; // Ideally, if the origin still exist on the server, we should continue searching...  but that'd be difficult
@@ -632,7 +646,7 @@ void ProcessDirectoryJob::processFileAnalyzeRemoteInfo(
 }
 
 void ProcessDirectoryJob::processFileAnalyzeLocalInfo(
-    const SyncFileItemPtr &item, PathTuple path, const LocalInfo &localEntry,
+    const SyncFileItemPtr &item, const PathTuple &path, const LocalInfo &localEntry,
     const RemoteInfo &serverEntry, const SyncJournalFileRecord &dbEntry, QueryMode recurseQueryServer)
 {
     bool noServerEntry = (_queryServer != ParentNotChanged && !serverEntry.isValid())
@@ -658,7 +672,7 @@ void ProcessDirectoryJob::processFileAnalyzeLocalInfo(
 
     _childModified |= serverModified;
 
-    auto finalize = [&] {
+    auto finalize = [item, localEntry, serverEntry, this](const PathTuple &path, QueryMode recurseQueryServer) {
         bool recurse = item->isDirectory() || localEntry.isDirectory || serverEntry.isDirectory;
         // Even if we have a local directory: If the remote is a file that's propagated as a
         // conflict we don't need to recurse into it. (local c1.owncloud, c1/ ; remote: c1)
@@ -705,7 +719,7 @@ void ProcessDirectoryJob::processFileAnalyzeLocalInfo(
             }
         }
 
-        finalize();
+        finalize(path, recurseQueryServer);
         return;
     }
 
@@ -807,7 +821,7 @@ void ProcessDirectoryJob::processFileAnalyzeLocalInfo(
             }
         }
 
-        finalize();
+        finalize(path, recurseQueryServer);
         return;
     }
 
@@ -818,11 +832,11 @@ void ProcessDirectoryJob::processFileAnalyzeLocalInfo(
         // The instruction should already be set correctly.
         OC_ASSERT(item->_instruction == CSYNC_INSTRUCTION_UPDATE_METADATA);
         OC_ASSERT(item->_type == ItemTypeVirtualFile);
-        finalize();
+        finalize(path, recurseQueryServer);
         return;
     } else if (serverModified) {
         processFileConflict(item, path, localEntry, serverEntry, dbEntry);
-        finalize();
+        finalize(path, recurseQueryServer);
         return;
     }
 
@@ -835,7 +849,7 @@ void ProcessDirectoryJob::processFileAnalyzeLocalInfo(
     item->_type = localEntry.isDirectory ? ItemTypeDirectory : localEntry.isVirtualFile ? ItemTypeVirtualFile : ItemTypeFile;
     _childModified = true;
 
-    auto postProcessLocalNew = [item, localEntry, path, this]() {
+    auto postProcessLocalNew = [item, localEntry, this](const PathTuple &path) {
         if (localEntry.isVirtualFile) {
             const bool isPlaceHolder = _discoveryData->_syncOptions._vfs->isDehydratedPlaceholder(_discoveryData->_localDir + path._local);
             if (isPlaceHolder) {
@@ -909,9 +923,9 @@ void ProcessDirectoryJob::processFileAnalyzeLocalInfo(
 
     // If it's not a move it's just a local-NEW
     if (!moveCheck()) {
-       postProcessLocalNew();
-       finalize();
-       return;
+        postProcessLocalNew(path);
+        finalize(path, recurseQueryServer);
+        return;
     }
 
     // Check local permission if we are allowed to put move the file here
@@ -925,8 +939,8 @@ void ProcessDirectoryJob::processFileAnalyzeLocalInfo(
 
         // If we can create the destination, do that.
         // Permission errors on the destination will be handled by checkPermissions later.
-        postProcessLocalNew();
-        finalize();
+        postProcessLocalNew(path);
+        finalize(path, recurseQueryServer);
 
         // If the destination upload will work, we're fine with the source deletion.
         // If the source deletion can't work, checkPermissions will error.
@@ -945,14 +959,14 @@ void ProcessDirectoryJob::processFileAnalyzeLocalInfo(
         } else {
             // Signal to future checkPermissions() to forbid the REMOVE and set to restore instead
             qCInfo(lcDisco) << "Preventing future remove on source" << originalPath;
-            _discoveryData->_forbiddenDeletes[originalPath + QLatin1Char('/')] = true;
+            _discoveryData->_forbiddenDeletes.insert(originalPath + QLatin1Char('/'));
         }
         return;
     }
 
     auto wasDeletedOnClient = _discoveryData->findAndCancelDeletedJob(originalPath);
 
-    auto processRename = [item, originalPath, base, this](PathTuple &path) {
+    auto processRename = [item, originalPath, base, this](PathTuple path) {
         auto adjustedOriginalPath = _discoveryData->adjustRenamedPath(originalPath, SyncFileItem::Down);
         _discoveryData->_renamedItemsLocal.insert(originalPath, path._target);
         item->_renameTarget = path._target;
@@ -966,7 +980,7 @@ void ProcessDirectoryJob::processFileAnalyzeLocalInfo(
         item->_direction = SyncFileItem::Up;
         item->_fileId = base._fileId;
         item->_remotePerm = base._remotePerm;
-        item->_etag = base._etag;
+        item->_etag = QString::fromUtf8(base._etag);
         item->_type = base._type;
 
         // Discard any download/dehydrate tags on the base file.
@@ -978,10 +992,10 @@ void ProcessDirectoryJob::processFileAnalyzeLocalInfo(
             item->_type = ItemTypeFile;
 
         qCInfo(lcDisco) << "Rename detected (up) " << item->_file << " -> " << item->_renameTarget;
+        return path;
     };
     if (wasDeletedOnClient.first) {
-        recurseQueryServer = wasDeletedOnClient.second == base._etag ? ParentNotChanged : NormalQuery;
-        processRename(path);
+        finalize(processRename(path), wasDeletedOnClient.second.toUtf8() == base._etag ? ParentNotChanged : NormalQuery);
     } else {
         // We must query the server to know if the etag has not changed
         _pendingAsyncJobs++;
@@ -989,30 +1003,27 @@ void ProcessDirectoryJob::processFileAnalyzeLocalInfo(
         if (base.isVirtualFile() && isVfsWithSuffix()) {
             serverOriginalPath = chopVirtualFileSuffix(serverOriginalPath);
         }
-        auto job = new RequestEtagJob(_discoveryData->_account, serverOriginalPath, this);
-        connect(job, &RequestEtagJob::finishedWithResult, this, [=](const HttpResult<QByteArray> &etag) mutable {
-            if (!etag || (etag.get() != base._etag && !item->isDirectory()) || _discoveryData->isRenamed(originalPath)) {
-                qCInfo(lcDisco) << "Can't rename because the etag has changed or the directory is gone" << originalPath;
-                // Can't be a rename, leave it as a new.
-                postProcessLocalNew();
-            } else {
-                // In case the deleted item was discovered in parallel
-                _discoveryData->findAndCancelDeletedJob(originalPath);
-                processRename(path);
-                recurseQueryServer = etag.get() == base._etag ? ParentNotChanged : NormalQuery;
-            }
-            processFileFinalize(item, path, item->isDirectory(), NormalQuery, recurseQueryServer);
-            _pendingAsyncJobs--;
-            QTimer::singleShot(0, _discoveryData, &DiscoveryPhase::scheduleMoreJobs);
-        });
+        auto job = new RequestEtagJob(_discoveryData->_account, _discoveryData->_baseUrl, serverOriginalPath, this);
+        connect(job, &RequestEtagJob::finishedSignal, this,
+            [job, recurseQueryServer, path = path, postProcessLocalNew, processRename, base, item, originalPath, this] {
+                if (job->httpStatusCode() == 404 || (job->etag().toUtf8() != base._etag && !item->isDirectory()) || _discoveryData->isRenamed(originalPath)) {
+                    qCInfo(lcDisco) << "Can't rename because the etag has changed or the directory is gone" << originalPath;
+                    // Can't be a rename, leave it as a new.
+                    postProcessLocalNew(path);
+                    processFileFinalize(item, path, item->isDirectory(), NormalQuery, recurseQueryServer);
+                } else {
+                    // In case the deleted item was discovered in parallel
+                    _discoveryData->findAndCancelDeletedJob(originalPath);
+                    processFileFinalize(item, processRename(path), item->isDirectory(), NormalQuery, job->etag().toUtf8() == base._etag ? ParentNotChanged : NormalQuery);
+                }
+                _pendingAsyncJobs--;
+                QTimer::singleShot(0, _discoveryData, &DiscoveryPhase::scheduleMoreJobs);
+            });
         job->start();
-        return;
     }
-
-    finalize();
 }
 
-void ProcessDirectoryJob::processFileConflict(const SyncFileItemPtr &item, ProcessDirectoryJob::PathTuple path, const LocalInfo &localEntry, const RemoteInfo &serverEntry, const SyncJournalFileRecord &dbEntry)
+void ProcessDirectoryJob::processFileConflict(const SyncFileItemPtr &item, const ProcessDirectoryJob::PathTuple &path, const LocalInfo &localEntry, const RemoteInfo &serverEntry, const SyncJournalFileRecord &dbEntry)
 {
     item->_previousSize = localEntry.size;
     item->_previousModtime = localEntry.modtime;
@@ -1030,8 +1041,14 @@ void ProcessDirectoryJob::processFileConflict(const SyncFileItemPtr &item, Proce
     // If there's no content hash, use heuristics
     if (serverEntry.checksumHeader.isEmpty()) {
         // If the size or mtime is different, it's definitely a conflict.
-        bool isConflict = (serverEntry.size != localEntry.size) || (serverEntry.modtime != localEntry.modtime);
-
+        bool sizeDiffers = serverEntry.size != localEntry.size;
+        bool modTimeDiffers = serverEntry.modtime != localEntry.modtime;
+        bool isConflict = sizeDiffers || modTimeDiffers;
+        if (isConflict) {
+            qCDebug(lcDisco) << serverEntry.name << ": detected conflict: size difference: " << sizeDiffers << "mtime difference: " << modTimeDiffers;
+        } else {
+            qCDebug(lcDisco) << serverEntry.name << ": no conflict detected";
+        }
         // It could be a conflict even if size and mtime match!
         //
         // In older client versions we always treated these cases as a
@@ -1222,11 +1239,12 @@ bool ProcessDirectoryJob::checkPermissions(const OCC::SyncFileItemPtr &item)
     }
     case CSYNC_INSTRUCTION_REMOVE: {
         QString fileSlash = item->_file + QLatin1Char('/');
-        auto forbiddenIt = _discoveryData->_forbiddenDeletes.upperBound(fileSlash);
-        if (forbiddenIt != _discoveryData->_forbiddenDeletes.begin())
-            forbiddenIt -= 1;
-        if (forbiddenIt != _discoveryData->_forbiddenDeletes.end()
-            && fileSlash.startsWith(forbiddenIt.key())) {
+        auto forbiddenIt = _discoveryData->_forbiddenDeletes.upper_bound(fileSlash);
+        if (forbiddenIt != _discoveryData->_forbiddenDeletes.cbegin()) {
+            forbiddenIt--;
+        }
+        if (forbiddenIt != _discoveryData->_forbiddenDeletes.cend()
+            && fileSlash.startsWith(*forbiddenIt)) {
             item->_instruction = CSYNC_INSTRUCTION_NEW;
             item->_direction = SyncFileItem::Down;
             item->_isRestoration = true;
@@ -1379,7 +1397,7 @@ QString ProcessDirectoryJob::chopVirtualFileSuffix(const QString &str) const
 
 DiscoverySingleDirectoryJob *ProcessDirectoryJob::startAsyncServerQuery()
 {
-    auto serverJob = new DiscoverySingleDirectoryJob(_discoveryData->_account,
+    auto serverJob = new DiscoverySingleDirectoryJob(_discoveryData->_account, _discoveryData->_baseUrl,
         _discoveryData->_remoteFolder + _currentFolder._server, this);
     if (!_dirItem)
         serverJob->setIsRootPath(); // query the fingerprint on the root
@@ -1414,7 +1432,7 @@ DiscoverySingleDirectoryJob *ProcessDirectoryJob::startAsyncServerQuery()
             } else {
                 // Fatal for the root job since it has no SyncFileItem, or for the network errors
                 emit _discoveryData->fatalError(tr("Server replied with an error while reading directory '%1' : %2")
-                    .arg(_currentFolder._server, results.error().message));
+                                                    .arg(_currentFolder._server.isEmpty() ? QStringLiteral("/") : _currentFolder._server, results.error().message));
             }
         }
     });
