@@ -1,14 +1,15 @@
 import os
 import requests
+from helpers.ConfigHelper import get_config
 
 createdUsers = {}
 
 # gets all users information created in a test scenario
-def getCreatedUsersFromMiddleware(context):
+def getCreatedUsersFromMiddleware():
     createdUsers = {}
     try:
         res = requests.get(
-            os.path.join(context.userData['middlewareUrl'], 'state'),
+            os.path.join(get_config('middlewareUrl'), 'state'),
             headers={"Content-Type": "application/json"},
         )
         createdUsers = res.json()['created_users']
@@ -18,7 +19,7 @@ def getCreatedUsersFromMiddleware(context):
     return createdUsers
 
 
-def getUserInfo(context, username, attribute):
+def getUserInfo(username, attribute):
     # add and update users to the global createdUsers dict if not already there
     # so that we don't have to request for user information in every scenario
     # but instead get user information from the global dict
@@ -26,13 +27,13 @@ def getUserInfo(context, username, attribute):
     if username in createdUsers:
         return createdUsers[username][attribute]
     else:
-        createdUsers = {**createdUsers, **getCreatedUsersFromMiddleware(context)}
+        createdUsers = {**createdUsers, **getCreatedUsersFromMiddleware()}
         return createdUsers[username][attribute]
 
 
-def getDisplaynameForUser(context, username):
-    return getUserInfo(context, username, 'displayname')
+def getDisplaynameForUser(username):
+    return getUserInfo(username, 'displayname')
 
 
-def getPasswordForUser(context, username):
-    return getUserInfo(context, username, 'password')
+def getPasswordForUser(username):
+    return getUserInfo(username, 'password')
